OC.L10N.register(
    "files_rightclick",
    {
    "Unselect" : "Deselecteren",
    "Share folder" : "Map delen",
    "Share file" : "Bestand delen",
    "Select" : "Selecteer",
    "Copied !" : "Gekopieerd!",
    "Right click" : "Rechterklik",
    "Right click menu for Nextcloud" : "Rechts-klik-menu voor Nextcloud",
    "This app allows users and developers to have a right click menu. Simply use the RightClick object to quickly create context menus. The Files app already shows the actions menu when right clicking on files and folders." : "Met deze app introduceert  een menu bij rechts-klikken voor gebruikers en ontwikkelaars. Gebruik het RightClick object om contextueel menu te maken. Rechts-klikken op bestanden en mappen wordt al ondersteunt in de Bestanden app."
},
"nplurals=2; plural=(n != 1);");
